package com.tfg.om.web.controller.rest;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.jeveris.core.rest.service.response.wrapper.RestResponse;
import com.tfg.om.business.model.Contacto;
import com.tfg.om.business.model.Oficina;
import com.tfg.om.web.service.IContactoWS;

@Controller
@RequestMapping("/contacto")
public class ContactoRestController {

	private static final Logger LOGGER = LoggerFactory
			.getLogger(ContactoRestController.class);
    
	@Autowired
	private IContactoWS contacntoService;

	/**
	 * obtiene el listado de contactos por oficina
	 * 
	 * @param
	 * @return listado de contactos por oficina
	 */
	@RequestMapping(value = "getContactos", method = RequestMethod.POST)
	@ResponseBody
	public List<Contacto> getContactosByOficina(@RequestBody Oficina oficina) {
		List<Contacto> contactos;
		
		contactos = contacntoService.getContactosByOficina(oficina);
			
		return contactos;
	}	
	
	/**
	 * agrega un contacto
	 * 
	 * @param contaco Nombre del contacto
	 * @param oficina Oficina asociada a ese contacto
	 * @return resultado al guardar
	 */
	@RequestMapping(value = "setCliente/{cliente}/{oficina}/{pais}/{ciudad}", method = RequestMethod.GET)
	@ResponseBody
	public RestResponse<String> setCliente(@PathVariable String cliente , @PathVariable String oficina,@PathVariable String pais , @PathVariable String ciudad) {
		if (LOGGER.isDebugEnabled()) {
			LOGGER.debug("Invocado el servicio GET contacto/setCliente  ");
		}

		contacntoService.setContacto(cliente,oficina,pais,ciudad);
		
		RestResponse<String> resp = new RestResponse<String>();

		try {
			resp.setResponse("ok");
			resp.setSuccess(true);

		} catch (Exception e) {
			resp.setResponse("error");
			resp.setSuccess(false);
			resp.setErrorMessage(e.getMessage());
		}

		return resp;
	}
	
	/**
	 * obtiene el listado de contactos
	 * 
	 * @param
	 * @return listado de contactos
	 */
	@RequestMapping(value = "getContactos", method = RequestMethod.GET)
	@ResponseBody
	public List<Contacto> getAllContactos() {
		return contacntoService.getAllContactos();
	}	
	
	/**
	 * agrega un contacto
	 * 
	 */
	@RequestMapping(value = "contacto", method = RequestMethod.GET)
	@ResponseBody
	public void nuevaContacto(@RequestBody Contacto contacto) {

		contacntoService.setContacto(contacto);
	}
	
	/**
	 * modifica un contacto con identificador id
	 * @param oficina
	 */
	@RequestMapping(value = "contacto/{id}", method = RequestMethod.GET)
	@ResponseBody
	public void updateContacto(@RequestBody Contacto contacto) {
		contacntoService.updateContacto(contacto);
	}
	
}
