package com.tfg.om.web.controller.rest;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.jeveris.core.rest.service.response.wrapper.RestResponse;
import com.tfg.om.business.model.Lugar;
import com.tfg.om.business.model.Oficina;
import com.tfg.om.web.service.ILugaresWS;

@Controller
@RequestMapping("/lugares")
public class LugaresRestController {

	private static final Logger LOGGER = LoggerFactory
			.getLogger(LugaresRestController.class);

	@Autowired
	private ILugaresWS lugaresService;

	/**
	 * obtiene los Paises
	 * 
	 * @param
	 * @return lista de los paises
	 */
	@RequestMapping(value = "getPaises", method = RequestMethod.GET)
	@ResponseBody
	public RestResponse<ArrayList<Lugar>> getPaises() {
		if (LOGGER.isDebugEnabled()) {
			LOGGER.debug("Invocado el servicio GET getLugares  ");
		}

		System.err.println("[Obteniedo lista de Paises]");
		RestResponse<ArrayList<Lugar>> resp = new RestResponse<ArrayList<Lugar>>();

		try {
			resp.setResponse(lugaresService.getAllPaises());
			resp.setSuccess(true);

		} catch (Exception e) {
			resp.setSuccess(false);
			resp.setErrorMessage(e.getMessage());
		}

		return resp;
	}
	
	

	/**
	 * obtiene las ciudades del Pais indicado
	 * 
	 * @param	pais
	 * @return lista de los ciudades de ese pais
	 */
	@RequestMapping(value = "getCiudades/{pais}", method = RequestMethod.GET)
	@ResponseBody
	public List<Lugar> getCiudades(@PathVariable String pais) {
		return lugaresService.getCiudades(pais);
	}

	/**
	 * obtiene las oficinas de un lugar
	 * 
	 * @param	pais
	 * @return lista de los ciudades de ese pais
	 */
	@RequestMapping(value = "getOficinas", method = RequestMethod.POST)
	@ResponseBody
	public List<Oficina> getOficinas(@RequestBody Lugar lugar) {
		List<Oficina> oficinas;
		oficinas = lugaresService.getOficinas(lugar);
		return oficinas;
	}
	
	/**
	 * agrega una oficina
	 * 
	 * @param pais
	 * @param ciudad
	 */
	@RequestMapping(value = "setOficina", method = RequestMethod.POST)
	@ResponseBody
	public RestResponse<String> setLugar(@RequestBody Oficina oficina) {

		RestResponse<String> resp = new RestResponse<String>();
				
			lugaresService.setOficina(oficina);
			
			resp.setResponse("ok");
			resp.setSuccess(true);
		
		return resp;

	}

	
	
	
	/**
	 * agrega un lugar
	 * 
	 * @param pais
	 * @param ciudad
	 */
	@RequestMapping(value = "setLugar/{pais}/{ciudad}", method = RequestMethod.GET)
	@ResponseBody
	public void setLugar(@PathVariable String pais , @PathVariable String ciudad) {

		RestResponse<String> resp = new RestResponse<String>();

		try {
			
			lugaresService.setLugares( pais , ciudad);
			
			resp.setSuccess(true);

		} catch (Exception e) {
			resp.setSuccess(false);
			resp.setErrorMessage(e.getMessage());
		}

	}
	
	
	/**
	 * obtiene el listado de lugares
	 * 
	 * @param
	 * @return listado de oficinas
	 */
	@RequestMapping(value = "getLugares", method = RequestMethod.GET)
	@ResponseBody
	public List<Lugar> getLugar() {
		return lugaresService.getAllLugares();
	}
}
