package com.tfg.om.web.controller.rest;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.codehaus.jackson.map.util.JSONPObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.jeveris.core.rest.service.response.wrapper.RestResponse;
import com.tfg.om.business.model.Cliente;
import com.tfg.om.business.model.Contacto;
import com.tfg.om.business.model.Estado;
import com.tfg.om.business.model.Oportunidad;
import com.tfg.om.web.beans.OmBean;
import com.tfg.om.web.service.IOportunidadWS;

@Controller
@RequestMapping("/oportunidad")
public class OportunidadRestController {

	private static final Logger LOGGER = LoggerFactory
			.getLogger(OportunidadRestController.class);
	
    
	@Autowired
	private IOportunidadWS oportunidadService;

	/**
	 * obtiene el numero de oportunidades de cada tipo
	 * 
	 * @param
	 * @return numero de oportunidades de cada tipo separado por comas
	 */
	@RequestMapping(value = "getPorcentajes", method = RequestMethod.GET)
	@ResponseBody
	public RestResponse<String> getPorcentajes() {
		if (LOGGER.isDebugEnabled()) {
			LOGGER.debug("Invocado el servicio REST accounts/getPorcentajes  ");
		}

		RestResponse<String> resp = new RestResponse<String>();

		try {
			String porcentajes = oportunidadService.getPorcentajes().toString();

			// eliminamos el primer y ultimo caracter
			porcentajes = porcentajes.substring(1, porcentajes.length() - 1);

			resp.setResponse(porcentajes);
			resp.setSuccess(true);

		} catch (Exception e) {
			resp.setSuccess(false);
			resp.setErrorMessage(e.getMessage());
		}

		return resp;
	}

	/**
	 * obtiene las oportunidades
	 * 
	 * @param
	 * @return lista de las oportunidades
	 */
	@RequestMapping(value = "oportunidades", method = RequestMethod.GET)
	@ResponseBody
	public List<Oportunidad> getOportunidades() {
//		if (LOGGER.isDebugEnabled()) {
//			LOGGER.debug("Invocado el servicio GET getOportunidades  ");
//		}
//
//		RestResponse<List<Oportunidad>> resp = new RestResponse<List<Oportunidad>>();
//
//		try {
//
//			resp.setResponse(oportunidadService.getAllOp());
//			resp.setSuccess(true);
//
//			System.err.println("numero de oportunidades: "
//					+ oportunidadService.getAllOp().size());
//			
//		} catch (Exception e) {
//			resp.setSuccess(false);
//			resp.setErrorMessage(e.getMessage());
//		}
//
//		return resp;
		
		return oportunidadService.getAllOp();
		
		
	}
	
	
	/**
	 * lista detallada de una oportunidad
	 * 
	 * @param id
	 * @return lista detallada de una oportunidad
	 */
	@RequestMapping(value = "oportunidad/{id}", method = RequestMethod.GET)
	@ResponseBody
	public Oportunidad getOportunidad(@PathVariable int id) {
		if (LOGGER.isDebugEnabled()) {
			LOGGER.debug("Invocado el servicio GET getOportunidad  ");
		}

		return oportunidadService.getOportunidad(id);
	}

	/**
	 * nueva oportunidad
	 * 
	 * @param oportunidad
	 * @return
	 */
	@RequestMapping(value = "oportunidad", method = RequestMethod.POST)
	@ResponseBody
	public void nuevaOportunidad(
			@RequestBody Oportunidad oportunidad) {
		
		oportunidadService.setOportunidad(oportunidad);
	}
	
	/**
	 * modificar oportunidad
	 * 
	 * @param oportunidad
	 * @return
	 */
	@RequestMapping(value = "oportunidad/{id}", method = RequestMethod.PUT)
	@ResponseBody
	public void updateOportunidad(
			@RequestBody Oportunidad oportunidad) {
		
		oportunidadService.updateOportunidad(oportunidad);
	}
	
	/**
	 * eliminar oportunidad
	 * 
	 * @param oportunidad
	 * @return
	 */
	@RequestMapping(value = "oportunidad/{id}", method = RequestMethod.DELETE)
	@ResponseBody
	public void removeOportunidad(@PathVariable int id) {
		
		oportunidadService.removeOportunidad(id);
	}
	

}
